@@ -1,9 +1,11 @@
+import ConfigParser
 import logging
 import os
 import subprocess
-import ConfigParser
-import monasca_setup.detection
+
 import monasca_setup.agent_config
+import monasca_setup.detection
+from monasca_setup.detection.utils import find_process_name
 
 from distutils.version import LooseVersion
 
@@ -31,7 +33,7 @@ class Libvirt(monasca_setup.detection.Plugin):
     def _detect(self):
         """Run detection, set self.available True if the service is detected.
         """
-        if (monasca_setup.detection.find_process_name('nova-api') is not None and
+        if (find_process_name('nova-api') is not None and
            os.path.isfile(nova_conf)):
             self.available = True
 
@@ -101,9 +103,9 @@ class Libvirt(monasca_setup.detection.Plugin):
 
     def dependencies_installed(self):
         try:
+            import novaclient
             import time
             import yaml
-            import novaclient
             # novaclient module versions were renamed in version 2.22
             if novaclient.__version__ < LooseVersion("2.22"):
                 import novaclient.v1_1.client
